{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Conexión con JDBC\n",
    "\n",
    "## Objetivos\n",
    "\n",
    "- Identificar y diferenciar los tipos de bases de datos.\n",
    "- Conocer las características y usos de cada tipo de base de datos.\n",
    "- Aprender a conectar una aplicación Java con una base de datos utilizando JDBC.\n",
    "- Implementar una conexión básica y realizar operaciones simples sobre una base de datos relacional.\n",
    "\n",
    "## Introducción\n",
    "\n",
    "En el desarrollo de software, las bases de datos juegan un papel fundamental en el almacenamiento y manejo eficiente de la información. Existen varios tipos de bases de datos, cada uno diseñado para diferentes aplicaciones, y es esencial para los desarrolladores saber cómo conectarse y manipular estas bases de datos desde sus aplicaciones. En Java, la interacción con las bases de datos se realiza a través de la API JDBC (Java Database Connectivity), que proporciona un estándar para conectar aplicaciones Java con bases de datos.\n",
    "\n",
    "En esta clase, exploraremos cómo realizar una conexión básica a una base de datos utilizando Java.\n",
    "\n",
    "## Conexión\n",
    "\n",
    "La conexión a una base de datos en Java se realiza a través de la API Java Database Connectivity (JDBC). JDBC proporciona una forma estandarizada de conectarse a bases de datos relacionales. El flujo básico de conexión es:\n",
    "\n",
    "1. Cargar el controlador JDBC.\n",
    "2. Establecer la conexión con la base de datos.\n",
    "3. Crear una declaración SQL y ejecutarla.\n",
    "4. Procesar los resultados.\n",
    "5. Cerrar la conexión.\n",
    "\n",
    "### Ejemplo de Conexión a MySQL en Java usando JDBC\n",
    "\n",
    "A continuación, te mostramos cómo realizar una conexión simple a una base de datos MySQL y ejecutar una consulta básica.\n",
    "\n",
    "### Configuración de la Base de Datos\n",
    "Antes de empezar, asegúrate de tener MySQL instalado y configurado. Crea una base de datos llamada `universidad` con una tabla `estudiantes`.\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [],
   "source": [
    "%maven com.mysql:mysql-connector-j:9.1.0"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [],
   "source": [
    "import java.sql.*;\n",
    "\n",
    "public class DatabaseConnection {\n",
    "    private static final String URL = \"jdbc:mysql://127.0.0.1:3306/Universidad\";\n",
    "    private static final String USER = \"dba\"; // Cambia 'root' por tu usuario de MySQL\n",
    "    private static final String PASSWORD = \"$123456789\"; // Cambia 'yourpassword' por tu contraseña de MySQL\n",
    "\n",
    "    public static Connection getConnection() throws SQLException {\n",
    "        return DriverManager.getConnection(URL, USER, PASSWORD);\n",
    "    }\n",
    "}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [],
   "source": [
    "import java.sql.*;\n",
    "\n",
    "//Creación de la tabla\n",
    "public class CreateTable {\n",
    "    public static void Create() {\n",
    "        String query = \"\"\"\n",
    "            CREATE TABLE IF NOT EXISTS Estudiantes (\n",
    "                `matricula` INT NOT NULL AUTO_INCREMENT,\n",
    "                `nombre` VARCHAR(50) NOT NULL,\n",
    "                `edad` INT NULL DEFAULT NULL,\n",
    "                `fechaNacimiento` DATE NULL DEFAULT NULL,\n",
    "                `direccion` VARCHAR(100) NULL DEFAULT NULL,\n",
    "                `telefono` VARCHAR(15) NULL DEFAULT NULL,\n",
    "                `correoElectronico` VARCHAR(100) NULL DEFAULT NULL,\n",
    "                PRIMARY KEY (`matricula`)\n",
    "                );\n",
    "            \"\"\";;\n",
    "        try (Connection connection = DatabaseConnection.getConnection();\n",
    "             Statement stmt = connection.createStatement()) {\n",
    "          \n",
    "              // Usando el método executeUpdate\n",
    "              int result = stmt.executeUpdate(query);\n",
    "              System.out.println(result);\n",
    "\n",
    "              // Usando el método execute\n",
    "              boolean result1 = stmt.execute(query);\n",
    "              System.out.println(result1);\n",
    "            \n",
    "        } catch (SQLException e) {\n",
    "            e.printStackTrace();\n",
    "        }\n",
    "    }\n",
    "\n",
    "    public static void main(String[] args) {\n",
    "        Create();\n",
    "    }\n",
    "  }\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [],
   "source": [
    "import java.sql.Connection;\n",
    "import java.sql.PreparedStatement;\n",
    "import java.sql.SQLException;\n",
    "\n",
    "public class InsertStudent {\n",
    "    public static void insert(int matricula, String nombre, int edad, String fechaNacimiento, String direccion, String telefono, String correoElectronico) {\n",
    "        String query = \"INSERT INTO Estudiantes (matricula, nombre, edad, fechaNacimiento, direccion, telefono, correoElectronico) VALUES (?, ?, ?, ?, ?, ?, ?)\";\n",
    "        try (Connection connection = DatabaseConnection.getConnection();\n",
    "             PreparedStatement preparedStatement = connection.prepareStatement(query)) {\n",
    "\n",
    "            preparedStatement.setInt(1, matricula);\n",
    "            preparedStatement.setString(2, nombre);\n",
    "            preparedStatement.setInt(3, edad);\n",
    "            preparedStatement.setString(4, fechaNacimiento);\n",
    "            preparedStatement.setString(5, direccion);\n",
    "            preparedStatement.setString(6, telefono);\n",
    "            preparedStatement.setString(7, correoElectronico);\n",
    "\n",
    "            int rowsInserted = preparedStatement.executeUpdate();\n",
    "            System.out.println(\"Estudiante insertado correctamente: \" + rowsInserted);\n",
    "        } catch (SQLException e) {\n",
    "            e.printStackTrace();\n",
    "        }\n",
    "    }\n",
    "\n",
    "    public static void main(String[] args) {\n",
    "        insert(1, \"Sebastian\", 27, \"2024-12-12\", \"calle \", \"3195140529\", \"saguileran@itc.edu.co\");\n",
    "    }\n",
    "}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [],
   "source": [
    "import java.sql.Connection;\n",
    "import java.sql.PreparedStatement;\n",
    "import java.sql.ResultSet;\n",
    "import java.sql.SQLException;\n",
    "\n",
    "public class SelectEstudents {\n",
    "    public static void selectAll() {\n",
    "        String query = \"SELECT * FROM Estudiantes\";\n",
    "        try (Connection connection = DatabaseConnection.getConnection();\n",
    "             PreparedStatement preparedStatement = connection.prepareStatement(query)) {\n",
    "\n",
    "            ResultSet resultSet = preparedStatement.executeQuery();\n",
    "\n",
    "            while (resultSet.next()) {\n",
    "                int matricula = resultSet.getInt(\"matricula\");\n",
    "                String nombre = resultSet.getString(\"nombre\");\n",
    "                int edad = resultSet.getInt(\"edad\");\n",
    "                \n",
    "                System.out.println(\"id: \" + matricula + \", Nombre: \" + nombre + \", Edad: \" + edad);\n",
    "            }\n",
    "        } catch (SQLException e) {\n",
    "            e.printStackTrace();\n",
    "        }\n",
    "    }\n",
    "\n",
    "    public static void main(String[] args) {\n",
    "        selectAll();\n",
    "    }\n",
    "}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "vscode": {
     "languageId": "java"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "0\n",
      "false\n"
     ]
    }
   ],
   "source": [
    "new CreateTable().main(null);\n",
    "//new InsertStudent().insert(1, \"Sebastian\", 27, \"2024-12-12\", \"calle \", \"3195140529\", \"saguileran@itc.edu.co\");\n",
    "new SelectEstudents().selectAll();"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Java",
   "language": "java",
   "name": "java"
  },
  "language_info": {
   "codemirror_mode": "java",
   "file_extension": ".jshell",
   "mimetype": "text/x-java-source",
   "name": "Java",
   "pygments_lexer": "java",
   "version": "23.0.1+11-39"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
